
/*  ___   ___  ___  _   _  ___   ___   ____ ___  ____  
 * / _ \ /___)/ _ \| | | |/ _ \ / _ \ / ___) _ \|    \ 
 *| |_| |___ | |_| | |_| | |_| | |_| ( (__| |_| | | | |
 * \___/(___/ \___/ \__  |\___/ \___(_)____)___/|_|_|_|
 *                  (____/ 
 * OSOYOO IoT Tutorial: Use OSOYOO IoT APP to display the name of the  
 *  pressed IR Button
 * For more details see: https://osoyoo.com/?p=52705
 */

#include <ESP8266WiFi.h>
#include <WiFiUdp.h>
#include <IRremoteESP8266.h>
#include <IRrecv.h>
#include <IRutils.h>

#ifndef STASSID
#define STASSID "***" // replace *** with your wifi SSID
#define STAPSK  "***" // replace *** with your wifi password
#endif

unsigned int localPort = 8888;      // local port to listen on

// buffers for receiving and sending data
char packetBuffer[UDP_TX_PACKET_MAX_SIZE + 1]; //buffer to hold incoming packet,
//char  ReplyBuffer[] = "acknowledged";       // a string to send back

WiFiUDP Udp;

int RECV_PIN = D2; //an IR detector/demodulatord is connected to GPIO pin D2
IRrecv irrecv(RECV_PIN);
decode_results results;
//IPAddress phoneIP=IPAddress(192,168,1,255);//if your Arduino IP is sth like 192.168.0.xx set this value to 192.168.0.255
 
void setup() {
 
  Serial.begin(115200);
  WiFi.mode(WIFI_STA);
  WiFi.begin(STASSID, STAPSK);
  while (WiFi.status() != WL_CONNECTED) {
  Serial.println('.');
  delay(500);
  }
  Serial.print("Connected! IP address: ");
  Serial.println(WiFi.localIP());
  Serial.printf("UDP server on port %d\n", localPort);
  Udp.begin(localPort);
  irrecv.enableIRIn(); // Start the receiver

}
 
unsigned long oldTime=0;
unsigned long currentTime=0;

void loop() {
    String msg = "";  
    if (irrecv.decode(&results)) 
    { 
      // print() & println() can't handle printing long longs. (uint64_t)
      Serial.println("");
      switch(results.value)
      {
          case 0xFFA25D:
          msg= "CH-";
          break;
          case 0xFF629D:
          msg= "CH";
          break;
          case 0xFFE21D:
          msg= "CH+";
          break;
          case 0xFF22DD:
          msg= "|<<";
          break;
          case 0xFF02FD:
          msg= ">>|";
          break ;  
          case 0xFFC23D:
          msg= ">|";
          break ;               
          case 0xFFE01F:
          msg= "-";
          break ;  
          case 0xFFA857:
          msg= "+";
          break ;  
          case 0xFF906F:
          msg= "EQ";
          break ;  
          case 0xFF6897:
          msg= "0";
          break ;  
          case 0xFF9867:
          msg= "100+";
          break ;
          case 0xFFB04F:
          msg= "200+";
          break ;
          case 0xFF30CF:
          msg= "1";
          break ;
          case 0xFF18E7:
          msg= "2";
          break ;
          case 0xFF7A85:
          msg= "3";
          break ;
          case 0xFF10EF:
          msg= "4";
          break ;
          case 0xFF38C7:
          msg= "5";
          break ;
          case 0xFF5AA5:
          msg= "6";
          break ;
          case 0xFF42BD:
          msg= "7";
          break ;
          case 0xFF4AB5:
          msg= "8";
          break ;
          case 0xFF52AD:
          msg= "9";
          break ;
          default: 
          Serial.println("Do not keep pressing the button!"); 
          Serial.println("Infrared remote control is directional!");     
        }
        delay(500);

    IPAddress phoneIP=Udp.remoteIP();  
    if (msg.length() != 0) {
        msg = "The IR button is   " + msg;
        msg += "\n";
        Serial.println(msg);
    }
    Udp.beginPacket(phoneIP, 8888);
    Udp.write(msg.c_str());
    Udp.endPacket();
    irrecv.resume();  // Receive the next value

    }
 }


 
